package com.os.ems.base.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.os.common.annotation.Log;
import com.os.common.core.controller.BaseController;
import com.os.common.core.domain.AjaxResult;
import com.os.common.enums.BusinessType;
import com.os.ems.base.domain.EmsAlarmActionStepImage;
import com.os.ems.base.service.IEmsAlarmActionStepImageService;
import com.os.common.utils.poi.ExcelUtil;
import com.os.common.core.page.TableDataInfo;

/**
 * 报警措施步骤图片Controller
 * 
 * @author zch
 * @date 2025-05-29
 */
@RestController
@RequestMapping("/ems/base/emsAlarmActionStepImage")
public class EmsAlarmActionStepImageController extends BaseController
{
    @Autowired
    private IEmsAlarmActionStepImageService emsAlarmActionStepImageService;

    /**
     * 查询报警措施步骤图片列表
     */
    @PreAuthorize("@ss.hasPermi('ems/base:emsAlarmActionStepImage:list')")
    @GetMapping("/list")
    public TableDataInfo list(EmsAlarmActionStepImage emsAlarmActionStepImage)
    {
        startPage();
        List<EmsAlarmActionStepImage> list = emsAlarmActionStepImageService.selectEmsAlarmActionStepImageList(emsAlarmActionStepImage);
        return getDataTable(list);
    }

    /**
     * 导出报警措施步骤图片列表
     */
    @PreAuthorize("@ss.hasPermi('ems/base:emsAlarmActionStepImage:export')")
    @Log(title = "报警措施步骤图片", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, EmsAlarmActionStepImage emsAlarmActionStepImage)
    {
        List<EmsAlarmActionStepImage> list = emsAlarmActionStepImageService.selectEmsAlarmActionStepImageList(emsAlarmActionStepImage);
        ExcelUtil<EmsAlarmActionStepImage> util = new ExcelUtil<EmsAlarmActionStepImage>(EmsAlarmActionStepImage.class);
        util.exportExcel(response, list, "报警措施步骤图片数据");
    }

    /**
     * 获取报警措施步骤图片详细信息
     */
    @PreAuthorize("@ss.hasPermi('ems/base:emsAlarmActionStepImage:query')")
    @GetMapping(value = "/{objId}")
    public AjaxResult getInfo(@PathVariable("objId") String objId)
    {
        return success(emsAlarmActionStepImageService.selectEmsAlarmActionStepImageByObjId(objId));
    }

    /**
     * 新增报警措施步骤图片
     */
    @PreAuthorize("@ss.hasPermi('ems/base:emsAlarmActionStepImage:add')")
    @Log(title = "报警措施步骤图片", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody EmsAlarmActionStepImage emsAlarmActionStepImage)
    {
        emsAlarmActionStepImage.setCreateBy(getUsername());
        return toAjax(emsAlarmActionStepImageService.insertEmsAlarmActionStepImage(emsAlarmActionStepImage));
    }

    /**
     * 修改报警措施步骤图片
     */
    @PreAuthorize("@ss.hasPermi('ems/base:emsAlarmActionStepImage:edit')")
    @Log(title = "报警措施步骤图片", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EmsAlarmActionStepImage emsAlarmActionStepImage)
    {
        emsAlarmActionStepImage.setUpdateBy(getUsername());
        return toAjax(emsAlarmActionStepImageService.updateEmsAlarmActionStepImage(emsAlarmActionStepImage));
    }

    /**
     * 删除报警措施步骤图片
     */
    @PreAuthorize("@ss.hasPermi('ems/base:emsAlarmActionStepImage:remove')")
    @Log(title = "报警措施步骤图片", businessType = BusinessType.DELETE)
	@DeleteMapping("/{objIds}")
    public AjaxResult remove(@PathVariable String[] objIds)
    {
        return toAjax(emsAlarmActionStepImageService.deleteEmsAlarmActionStepImageByObjIds(objIds));
    }
}
