package com.os.ems.info.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;
import com.os.common.annotation.Log;
import com.os.common.core.controller.BaseController;
import com.os.common.core.domain.AjaxResult;
import com.os.common.enums.BusinessType;
import com.os.ems.info.domain.PowerEnergySparePartsRegistration;
import com.os.ems.info.service.IPowerEnergySparePartsRegistrationService;
import com.os.common.utils.poi.ExcelUtil;
import com.os.common.core.page.TableDataInfo;

/**
 * 动力能源部行输科废旧备件登记Controller
 * 
 * @author Yinq
 * @date 2025-06-06
 */
@RestController
@RequestMapping("/ems/info/sparePartsRegistration")
public class PowerEnergySparePartsRegistrationController extends BaseController
{
    @Autowired
    private IPowerEnergySparePartsRegistrationService powerEnergySparePartsRegistrationService;

    /**
     * 查询动力能源部行输科废旧备件登记列表
     */
    @PreAuthorize("@ss.hasPermi('ems/info:sparePartsRegistration:list')")
    @GetMapping("/list")
    public TableDataInfo list(PowerEnergySparePartsRegistration powerEnergySparePartsRegistration)
    {
        startPage();
        List<PowerEnergySparePartsRegistration> list = powerEnergySparePartsRegistrationService.selectPowerEnergySparePartsRegistrationList(powerEnergySparePartsRegistration);
        return getDataTable(list);
    }

    /**
     * 导出动力能源部行输科废旧备件登记列表
     */
    @PreAuthorize("@ss.hasPermi('ems/info:sparePartsRegistration:export')")
    @Log(title = "动力能源部行输科废旧备件登记", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PowerEnergySparePartsRegistration powerEnergySparePartsRegistration)
    {
        List<PowerEnergySparePartsRegistration> list = powerEnergySparePartsRegistrationService.selectPowerEnergySparePartsRegistrationList(powerEnergySparePartsRegistration);
        ExcelUtil<PowerEnergySparePartsRegistration> util = new ExcelUtil<PowerEnergySparePartsRegistration>(PowerEnergySparePartsRegistration.class);
        util.exportExcel(response, list, "动力能源部行输科废旧备件登记数据");
    }

    /**
     * 获取动力能源部行输科废旧备件登记详细信息
     */
    @PreAuthorize("@ss.hasPermi('ems/info:sparePartsRegistration:query')")
    @GetMapping(value = "/{objid}")
    public AjaxResult getInfo(@PathVariable("objid") Long objid)
    {
        return success(powerEnergySparePartsRegistrationService.selectPowerEnergySparePartsRegistrationByObjid(objid));
    }

    /**
     * 新增动力能源部行输科废旧备件登记
     */
    @PreAuthorize("@ss.hasPermi('ems/info:sparePartsRegistration:add')")
    @Log(title = "动力能源部行输科废旧备件登记", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PowerEnergySparePartsRegistration powerEnergySparePartsRegistration)
    {
        powerEnergySparePartsRegistration.setCreateBy(getUsername());
        return toAjax(powerEnergySparePartsRegistrationService.insertPowerEnergySparePartsRegistration(powerEnergySparePartsRegistration));
    }

    /**
     * 修改动力能源部行输科废旧备件登记
     */
    @PreAuthorize("@ss.hasPermi('ems/info:sparePartsRegistration:edit')")
    @Log(title = "动力能源部行输科废旧备件登记", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PowerEnergySparePartsRegistration powerEnergySparePartsRegistration)
    {
        powerEnergySparePartsRegistration.setUpdateBy(getUsername());
        return toAjax(powerEnergySparePartsRegistrationService.updatePowerEnergySparePartsRegistration(powerEnergySparePartsRegistration));
    }

    /**
     * 删除动力能源部行输科废旧备件登记
     */
    @PreAuthorize("@ss.hasPermi('ems/info:sparePartsRegistration:remove')")
    @Log(title = "动力能源部行输科废旧备件登记", businessType = BusinessType.DELETE)
	@DeleteMapping("/{objids}")
    public AjaxResult remove(@PathVariable Long[] objids)
    {
        return toAjax(powerEnergySparePartsRegistrationService.deletePowerEnergySparePartsRegistrationByObjids(objids));
    }

    /**
     * 导入动力能源部行输科废旧备件登记数据
     */
    @PreAuthorize("@ss.hasPermi('ems/info:sparePartsRegistration:add')")
    @Log(title = "动力能源部行输科废旧备件登记", businessType = BusinessType.IMPORT)
    @PostMapping("/importData")
    public AjaxResult importData(MultipartFile file, boolean updateSupport) throws Exception
    {
        ExcelUtil<PowerEnergySparePartsRegistration> util = new ExcelUtil<PowerEnergySparePartsRegistration>(PowerEnergySparePartsRegistration.class);
        List<PowerEnergySparePartsRegistration> registrationList = util.importExcel(file.getInputStream());
        String operName = getUsername();
        String message = powerEnergySparePartsRegistrationService.importPowerEnergySparePartsRegistration(registrationList, updateSupport, operName);
        return AjaxResult.success(message);
    }

    /**
     * 获取动力能源部行输科废旧备件登记导入模板
     */
    @PostMapping("/importTemplate")
    public AjaxResult importTemplate()
    {
        ExcelUtil<PowerEnergySparePartsRegistration> util = new ExcelUtil<PowerEnergySparePartsRegistration>(PowerEnergySparePartsRegistration.class);
        return util.importTemplateExcel("动力能源部行输科废旧备件登记数据");
    }
}
