package com.os.ems.info.service;

import java.util.List;
import com.os.ems.info.domain.DailyFaultRecord;

/**
 * 日常故障记录Service接口
 * 
 * @author Yinq
 * @date 2025-06-05
 */
public interface IDailyFaultRecordService 
{
    /**
     * 查询日常故障记录
     * 
     * @param id 日常故障记录主键
     * @return 日常故障记录
     */
    public DailyFaultRecord selectDailyFaultRecordById(Long id);

    /**
     * 查询日常故障记录列表
     * 
     * @param dailyFaultRecord 日常故障记录
     * @return 日常故障记录集合
     */
    public List<DailyFaultRecord> selectDailyFaultRecordList(DailyFaultRecord dailyFaultRecord);

    /**
     * 新增日常故障记录
     * 
     * @param dailyFaultRecord 日常故障记录
     * @return 结果
     */
    public int insertDailyFaultRecord(DailyFaultRecord dailyFaultRecord);

    /**
     * 修改日常故障记录
     * 
     * @param dailyFaultRecord 日常故障记录
     * @return 结果
     */
    public int updateDailyFaultRecord(DailyFaultRecord dailyFaultRecord);

    /**
     * 批量删除日常故障记录
     * 
     * @param ids 需要删除的日常故障记录主键集合
     * @return 结果
     */
    public int deleteDailyFaultRecordByIds(Long[] ids);

    /**
     * 删除日常故障记录信息
     * 
     * @param id 日常故障记录主键
     * @return 结果
     */
    public int deleteDailyFaultRecordById(Long id);

    /**
     * 导入日常故障记录数据
     *
     * @param recordList 记录数据列表
     * @param isUpdateSupport 是否更新支持，如果已存在，则进行更新数据
     * @param operName 操作用户
     * @return 结果
     */
    public String importDailyFaultRecord(List<DailyFaultRecord> recordList, Boolean isUpdateSupport, String operName);
}
