package com.os.ems.record.mapper;

import java.text.ParseException;
import java.util.List;
import java.util.Map;

import com.os.ems.record.domain.RecordIotenvInstant;
import org.apache.ibatis.annotations.Param;

/**
 * 物联网数据Mapper接口
 * 
 * @author zch
 * @date 2025-04-28
 */
public interface RecordIotenvInstantMapper 
{
    /**
     * 查询物联网数据
     * 
     * @param objid 物联网数据主键
     * @return 物联网数据
     */
    public RecordIotenvInstant selectRecordIotenvInstantByObjid(Long objid);

    /**
     * 查询物联网数据列表
     * 
     * @param recordIotenvInstant 物联网数据
     * @return 物联网数据集合
     */
    public List<RecordIotenvInstant> selectRecordIotenvInstantList(RecordIotenvInstant recordIotenvInstant);

    /**
     * 新增物联网数据
     * 
     * @param recordIotenvInstant 物联网数据
     * @return 结果
     */
    public int insertRecordIotenvInstant(RecordIotenvInstant recordIotenvInstant);

    /**
     * 修改物联网数据
     * 
     * @param recordIotenvInstant 物联网数据
     * @return 结果
     */
    public int updateRecordIotenvInstant(RecordIotenvInstant recordIotenvInstant);

    /**
     * 删除物联网数据
     * 
     * @param objid 物联网数据主键
     * @return 结果
     */
    public int deleteRecordIotenvInstantByObjid(Long objid);

    /**
     * 批量删除物联网数据
     * 
     * @param objids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRecordIotenvInstantByObjids(Long[] objids);


    /**
     * 根据指定表名查询物联网数据列表
     *
     * @param tableName 表名
     * @param recordIotenvInstant 查询条件
     * @return 物联网数据集合
     */
//    List<RecordIotenvInstant> selectRecordIotenvInstantListFromTable(@Param("tableName") String tableName,
//                                                                     @Param("record") RecordIotenvInstant recordIotenvInstant);

    /**
     * 使用 UNION ALL 从多个表查询物联网数据列表
     *
     * @param tableNames 表名列表
     * @param recordIotenvInstant 查询条件
     * @return 物联网数据集合
     */
    List<RecordIotenvInstant> selectRecordIotenvInstantListFromTables(@Param("tableNames") List<String> tableNames,
                                                                      @Param("recordIotenvInstant") RecordIotenvInstant recordIotenvInstant);



    /**
     * 分页查询物联网数据列表
     *
     * @param recordIotenvInstant 物联网数据
     * @return 物联网数据
     */
    List<RecordIotenvInstant> selectFromTablesWithPage(@Param("tableNames") List<String> tableNames,
                                                       @Param("recordIotenvInstant") RecordIotenvInstant recordIotenvInstant,
                                                       @Param("offset") int offset,
                                                       @Param("pageSize") int pageSize);

    /**
     * 检查表是否存在
     *
     * @param params 参数
     * @return 结果
     */
    Integer checkTableExists(Map<String, Object> params);


    /**
     * 统计多表查询的总记录数
     *
     * @param tableNames 表名列表
     * @param recordIotenvInstant 查询条件
     * @return 总记录数
     */
    int countFromTables(@Param("tableNames") List<String> tableNames, @Param("recordIotenvInstant") RecordIotenvInstant recordIotenvInstant);

    /**
     * 从指定表查询最新的N条记录
     * 
     * @param tableName 表名
     * @param limit 限制条数
     * @return 记录列表
     */
    public List<RecordIotenvInstant> selectLatestRecordsFromTable(@Param("tableName") String tableName, 
                                                                   @Param("limit") int limit);

    /**
     * 从指定表查询指定时间之后的记录
     * 
     * @param tableName 表名
     * @param startTime 开始时间
     * @return 记录列表
     */
    public List<RecordIotenvInstant> selectRecentRecordsFromTable(@Param("tableName") String tableName, 
                                                                   @Param("startTime") java.util.Date startTime);

    /**
     * 根据设备编号从指定表查询最新一条记录
     * 
     * @param tableName 表名
     * @param monitorId 设备编号
     * @return 最新记录
     */
    public RecordIotenvInstant selectLatestRecordByMonitorIdFromTable(@Param("tableName") String tableName, 
                                                                       @Param("monitorId") String monitorId);

    /**
     * 批量查询多个设备在指定表中的最新记录
     * 
     * @param tableName 表名
     * @param monitorIds 设备编号列表
     * @return 最新记录列表
     */
    public List<RecordIotenvInstant> selectLatestRecordsByMonitorIdsFromTable(@Param("tableName") String tableName, 
                                                                               @Param("monitorIds") List<String> monitorIds);
}
