package com.os.ems.record.service;

import java.util.List;
import com.os.ems.record.domain.EmsRecordAlarmData;

/**
 * 异常数据记录Service接口
 * 
 * @author Yinq
 * @date 2024-05-15
 */
public interface IEmsRecordAlarmDataService 
{
    /**
     * 查询异常数据记录
     * 
     * @param objId 异常数据记录主键
     * @return 异常数据记录
     */
    public EmsRecordAlarmData selectEmsRecordAlarmDataByObjId(Long objId);

    /**
     * 查询异常数据记录列表
     * 
     * @param emsRecordAlarmData 异常数据记录
     * @return 异常数据记录集合
     */
    public List<EmsRecordAlarmData> selectEmsRecordAlarmDataList(EmsRecordAlarmData emsRecordAlarmData);

    /**
     * 新增异常数据记录
     * 
     * @param emsRecordAlarmData 异常数据记录
     * @return 结果
     */
    public int insertEmsRecordAlarmData(EmsRecordAlarmData emsRecordAlarmData);

    /**
     * 修改异常数据记录
     * 
     * @param emsRecordAlarmData 异常数据记录
     * @return 结果
     */
    public int updateEmsRecordAlarmData(EmsRecordAlarmData emsRecordAlarmData);

    /**
     * 批量删除异常数据记录
     * 
     * @param objIds 需要删除的异常数据记录主键集合
     * @return 结果
     */
    public int deleteEmsRecordAlarmDataByObjIds(Long[] objIds);

    /**
     * 删除异常数据记录信息
     * 
     * @param objId 异常数据记录主键
     * @return 结果
     */
    public int deleteEmsRecordAlarmDataByObjId(Long objId);

    /**
     * 处理异常数据
     * @param objIds
     * @return
     */
    int handleExceptionsAlarmData(Long[] objIds);

    /**
     * 物联网数据阈值检查定时任务
     */
//    void checkIotenvThresholdAlarms();

    /**
     * 获取异常数据表总数（包含所有告警类型）
     */
    public int getAlarmDataTotalCount();

    /**
     * 批量保存WebSocket告警数据
     * 处理前端传来的告警数据列表，进行去重和批量插入
     * 
     * @param alarmDataList 告警数据列表
     * @return 实际插入的记录数量
     */
    public int saveWebSocketAlarmDataBatch(List<EmsRecordAlarmData> alarmDataList);
}
