package com.os.mes.base.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.os.common.annotation.Log;
import com.os.common.core.controller.BaseController;
import com.os.common.core.domain.AjaxResult;
import com.os.common.enums.BusinessType;
import com.os.mes.base.domain.BaseDeviceParam;
import com.os.mes.base.service.IBaseDeviceParamService;
import com.os.common.utils.poi.ExcelUtil;
import com.os.common.core.page.TableDataInfo;

/**
 * 设备参数Controller
 * 
 * @author Yinq
 * @date 2024-05-10
 */
@RestController
@RequestMapping("/mes/base/baseDeviceParam")
public class BaseDeviceParamController extends BaseController
{
    @Autowired
    private IBaseDeviceParamService baseDeviceParamService;

    /**
     * 查询设备参数列表
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseDeviceParam:list')")
    @GetMapping("/list")
    public TableDataInfo list(BaseDeviceParam baseDeviceParam)
    {
        startPage();
        List<BaseDeviceParam> list = baseDeviceParamService.selectBaseDeviceParamList(baseDeviceParam);
        return getDataTable(list);
    }

    /**
     * 导出设备参数列表
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseDeviceParam:export')")
    @Log(title = "设备参数", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BaseDeviceParam baseDeviceParam)
    {
        List<BaseDeviceParam> list = baseDeviceParamService.selectBaseDeviceParamList(baseDeviceParam);
        ExcelUtil<BaseDeviceParam> util = new ExcelUtil<BaseDeviceParam>(BaseDeviceParam.class);
        util.exportExcel(response, list, "设备参数数据");
    }

    /**
     * 获取设备参数详细信息
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseDeviceParam:query')")
    @GetMapping(value = "/{objId}")
    public AjaxResult getInfo(@PathVariable("objId") Long objId)
    {
        return success(baseDeviceParamService.selectBaseDeviceParamByObjId(objId));
    }

    /**
     * 新增设备参数
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseDeviceParam:add')")
    @Log(title = "设备参数", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BaseDeviceParam baseDeviceParam)
    {
        baseDeviceParam.setCreateBy(getUsername());
        return toAjax(baseDeviceParamService.insertBaseDeviceParam(baseDeviceParam));
    }

    /**
     * 修改设备参数
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseDeviceParam:edit')")
    @Log(title = "设备参数", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BaseDeviceParam baseDeviceParam)
    {
        baseDeviceParam.setUpdateBy(getUsername());
        return toAjax(baseDeviceParamService.updateBaseDeviceParam(baseDeviceParam));
    }

    /**
     * 删除设备参数
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseDeviceParam:remove')")
    @Log(title = "设备参数", businessType = BusinessType.DELETE)
	@DeleteMapping("/{objIds}")
    public AjaxResult remove(@PathVariable Long[] objIds)
    {
        return toAjax(baseDeviceParamService.deleteBaseDeviceParamByObjIds(objIds));
    }
}
