package com.os.mes.base.domain;

import java.math.BigDecimal;
import java.util.Date;
import com.fasterxml.jackson.annotation.JsonFormat;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;
import com.os.common.annotation.Excel;
import com.os.common.core.domain.BaseEntity;

/**
 * 产线/工位信息对象 base_product_line
 * 
 * @author Yinq
 * @date 2024-05-10
 */
public class BaseProductLine extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    /** 主键标识 */
    private Long objId;

    /** 所属工厂编号 */
    @Excel(name = "所属工厂编号")
    private String plantCode;

    /** 所属工厂名称 */
    @Excel(name = "所属工厂名称")
    private String factoryName;

    /** 产线编号 */
    @Excel(name = "产线编号")
    private String productLineCode;

    /** 产线名称 */
    @Excel(name = "产线名称")
    private String productLineName;

    /** 工位编号 */
    @Excel(name = "工位编号")
    private String stationCode;

    /** 工位名称 */
    @Excel(name = "工位名称")
    private String stationName;

    /** 类别（1产线 2工位） */
    @Excel(name = "类别", readConverterExp = "1=产线,2=工位")
    private String productLineType;

    /** 启用标识（0启用 1停用） */
    @Excel(name = "启用标识", readConverterExp = "0=启用,1=停用")
    private String isFlag;

    /** 创建人 */
    @Excel(name = "创建人")
    private String createdBy;

    /** 创建时间 */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "创建时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    private Date createdTime;

    /** 更新人 */
    @Excel(name = "更新人")
    private String updatedBy;

    /** 更新时间 */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "更新时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    private Date updatedTime;

    /** 父级编号 */
    @Excel(name = "父级编号")
    private String parentId;

    /** 工位类型（1生产工位 2质检工位） */
    @Excel(name = "工位类型", readConverterExp = "1=生产工位,2=质检工位")
    private String stationType;

    /** SAP工作中心编号 */
    @Excel(name = "SAP工作中心编号")
    private String workCenterCode;

    /** SAP工作中心描述 */
    @Excel(name = "SAP工作中心描述")
    private String workCenterName;

    /** 执行顺序 */
    @Excel(name = "执行顺序")
    private String executionSort;

    /** 日产能(米) */
    @Excel(name = "日产能(米)")
    private BigDecimal capacityDay;

    /** 月产能(米) */
    @Excel(name = "月产能(米)")
    private BigDecimal capacityMonth;

    public String getFactoryName() {
        return factoryName;
    }

    public void setFactoryName(String factoryName) {
        this.factoryName = factoryName;
    }

    public String getStationCode() {
        return stationCode;
    }

    public void setStationCode(String stationCode) {
        this.stationCode = stationCode;
    }

    public String getStationName() {
        return stationName;
    }

    public void setStationName(String stationName) {
        this.stationName = stationName;
    }

    public void setObjId(Long objId)
    {
        this.objId = objId;
    }

    public Long getObjId() 
    {
        return objId;
    }
    public void setProductLineCode(String productLineCode) 
    {
        this.productLineCode = productLineCode;
    }

    public String getProductLineCode() 
    {
        return productLineCode;
    }
    public void setProductLineName(String productLineName) 
    {
        this.productLineName = productLineName;
    }

    public String getProductLineName() 
    {
        return productLineName;
    }
    public void setProductLineType(String productLineType) 
    {
        this.productLineType = productLineType;
    }

    public String getProductLineType() 
    {
        return productLineType;
    }
    public void setPlantCode(String plantCode) 
    {
        this.plantCode = plantCode;
    }

    public String getPlantCode() 
    {
        return plantCode;
    }
    public void setIsFlag(String isFlag) 
    {
        this.isFlag = isFlag;
    }

    public String getIsFlag() 
    {
        return isFlag;
    }
    public void setCreatedBy(String createdBy) 
    {
        this.createdBy = createdBy;
    }

    public String getCreatedBy() 
    {
        return createdBy;
    }
    public void setCreatedTime(Date createdTime) 
    {
        this.createdTime = createdTime;
    }

    public Date getCreatedTime() 
    {
        return createdTime;
    }
    public void setUpdatedBy(String updatedBy) 
    {
        this.updatedBy = updatedBy;
    }

    public String getUpdatedBy() 
    {
        return updatedBy;
    }
    public void setUpdatedTime(Date updatedTime) 
    {
        this.updatedTime = updatedTime;
    }

    public Date getUpdatedTime() 
    {
        return updatedTime;
    }
    public void setParentId(String parentId) 
    {
        this.parentId = parentId;
    }

    public String getParentId() 
    {
        return parentId;
    }
    public void setStationType(String stationType) 
    {
        this.stationType = stationType;
    }

    public String getStationType() 
    {
        return stationType;
    }
    public void setWorkCenterCode(String workCenterCode) 
    {
        this.workCenterCode = workCenterCode;
    }

    public String getWorkCenterCode() 
    {
        return workCenterCode;
    }
    public void setWorkCenterName(String workCenterName) 
    {
        this.workCenterName = workCenterName;
    }

    public String getWorkCenterName() 
    {
        return workCenterName;
    }
    public void setExecutionSort(String executionSort) 
    {
        this.executionSort = executionSort;
    }

    public String getExecutionSort() 
    {
        return executionSort;
    }
    public void setCapacityDay(BigDecimal capacityDay) 
    {
        this.capacityDay = capacityDay;
    }

    public BigDecimal getCapacityDay() 
    {
        return capacityDay;
    }
    public void setCapacityMonth(BigDecimal capacityMonth) 
    {
        this.capacityMonth = capacityMonth;
    }

    public BigDecimal getCapacityMonth() 
    {
        return capacityMonth;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this,ToStringStyle.MULTI_LINE_STYLE)
            .append("objId", getObjId())
            .append("productLineCode", getProductLineCode())
            .append("productLineName", getProductLineName())
            .append("productLineType", getProductLineType())
            .append("plantCode", getPlantCode())
            .append("isFlag", getIsFlag())
            .append("createdBy", getCreatedBy())
            .append("createdTime", getCreatedTime())
            .append("updatedBy", getUpdatedBy())
            .append("updatedTime", getUpdatedTime())
            .append("parentId", getParentId())
            .append("stationType", getStationType())
            .append("workCenterCode", getWorkCenterCode())
            .append("workCenterName", getWorkCenterName())
            .append("executionSort", getExecutionSort())
            .append("capacityDay", getCapacityDay())
            .append("capacityMonth", getCapacityMonth())
            .toString();
    }
}
