package com.os.mes.base.service.impl;

import java.util.List;

import com.os.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.os.mes.base.mapper.BaseCustomDataMapper;
import com.os.mes.base.domain.BaseCustomData;
import com.os.mes.base.service.IBaseCustomDataService;

/**
 * 自定义数据维护Service业务层处理
 *
 * @author Yinq
 * @date 2024-05-10
 */
@Service
public class BaseCustomDataServiceImpl implements IBaseCustomDataService {
    @Autowired
    private BaseCustomDataMapper baseCustomDataMapper;

    /**
     * 查询自定义数据维护
     *
     * @param objId 自定义数据维护主键
     * @return 自定义数据维护
     */
    @Override
    public BaseCustomData selectBaseCustomDataByObjId(Long objId) {
        return baseCustomDataMapper.selectBaseCustomDataByObjId(objId);
    }

    /**
     * 查询自定义数据维护列表
     *
     * @param baseCustomData 自定义数据维护
     * @return 自定义数据维护
     */
    @Override
    public List<BaseCustomData> selectBaseCustomDataList(BaseCustomData baseCustomData) {
        return baseCustomDataMapper.selectBaseCustomDataList(baseCustomData);
    }

    /**
     * 新增自定义数据维护
     *
     * @param baseCustomData 自定义数据维护
     * @return 结果
     */
    @Override
    public int insertBaseCustomData(BaseCustomData baseCustomData) {
        baseCustomData.setCreateTime(DateUtils.getNowDate());
        return baseCustomDataMapper.insertBaseCustomData(baseCustomData);
    }

    /**
     * 修改自定义数据维护
     *
     * @param baseCustomData 自定义数据维护
     * @return 结果
     */
    @Override
    public int updateBaseCustomData(BaseCustomData baseCustomData) {
        baseCustomData.setUpdateTime(DateUtils.getNowDate());
        return baseCustomDataMapper.updateBaseCustomData(baseCustomData);
    }

    /**
     * 批量删除自定义数据维护
     *
     * @param objIds 需要删除的自定义数据维护主键
     * @return 结果
     */
    @Override
    public int deleteBaseCustomDataByObjIds(Long[] objIds) {
        return baseCustomDataMapper.deleteBaseCustomDataByObjIds(objIds);
    }

    /**
     * 删除自定义数据维护信息
     *
     * @param objId 自定义数据维护主键
     * @return 结果
     */
    @Override
    public int deleteBaseCustomDataByObjId(Long objId) {
        return baseCustomDataMapper.deleteBaseCustomDataByObjId(objId);
    }
}
