package com.os.mes.base.service.impl;

import java.util.List;

import com.os.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.os.mes.base.mapper.BaseFactoryMapper;
import com.os.mes.base.domain.BaseFactory;
import com.os.mes.base.service.IBaseFactoryService;

/**
 * 工厂管理Service业务层处理
 * 
 * @author Yinq
 * @date 2024-05-09
 */
@Service
public class BaseFactoryServiceImpl implements IBaseFactoryService 
{
    @Autowired
    private BaseFactoryMapper baseFactoryMapper;

    /**
     * 查询工厂管理
     * 
     * @param objId 工厂管理主键
     * @return 工厂管理
     */
    @Override
    public BaseFactory selectBaseFactoryByObjId(Long objId)
    {
        return baseFactoryMapper.selectBaseFactoryByObjId(objId);
    }

    /**
     * 查询工厂管理列表
     * 
     * @param baseFactory 工厂管理
     * @return 工厂管理
     */
    @Override
    public List<BaseFactory> selectBaseFactoryList(BaseFactory baseFactory)
    {
        return baseFactoryMapper.selectBaseFactoryList(baseFactory);
    }

    /**
     * 新增工厂管理
     * 
     * @param baseFactory 工厂管理
     * @return 结果
     */
    @Override
    public int insertBaseFactory(BaseFactory baseFactory)
    {
        baseFactory.setCreateTime(DateUtils.getNowDate());
        return baseFactoryMapper.insertBaseFactory(baseFactory);
    }

    /**
     * 修改工厂管理
     * 
     * @param baseFactory 工厂管理
     * @return 结果
     */
    @Override
    public int updateBaseFactory(BaseFactory baseFactory)
    {
        baseFactory.setUpdateTime(DateUtils.getNowDate());
        return baseFactoryMapper.updateBaseFactory(baseFactory);
    }

    /**
     * 批量删除工厂管理
     * 
     * @param objIds 需要删除的工厂管理主键
     * @return 结果
     */
    @Override
    public int deleteBaseFactoryByObjIds(Long[] objIds)
    {
        return baseFactoryMapper.deleteBaseFactoryByObjIds(objIds);
    }

    /**
     * 删除工厂管理信息
     * 
     * @param objId 工厂管理主键
     * @return 结果
     */
    @Override
    public int deleteBaseFactoryByObjId(Long objId)
    {
        return baseFactoryMapper.deleteBaseFactoryByObjId(objId);
    }
}
